@@ -1,7 +1,10 @@
 from django.db import models
 from django.template import Library
 from django.contrib.admin.templatetags.admin_list import result_headers
-from django.contrib.admin.util import lookup_field, display_for_field, label_for_field
+try:
+    from django.contrib.admin.util import lookup_field, display_for_field, label_for_field
+except ImportError:
+    from editor.utils import lookup_field, display_for_field, label_for_field
 from django.contrib.admin.views.main import EMPTY_CHANGELIST_VALUE
 from django.core.exceptions import ObjectDoesNotExist
 from django.utils.encoding import smart_unicode, force_unicode
